@@ -6,7 +6,15 @@ import pytest
 
 @pytest.mark.parametrize(
     "filename",
-    ["mkdocs-without-nbs.yml", "mkdocs-with-nbs.yml", "mkdocs-with-nbs-material.yml"],
+    [
+        "base-with-nbs-pys.yml",
+        "base-with-nbs.yml",
+        "base-with-pys.yml",
+        "base-without-nbs.yml",
+        "material-with-nbs-pys.yml",
+        "material-with-nbs.yml",
+        "material-with-pys.yml",
+    ],
 )
 def test_can_render_notebook(filename):
     this_dir = os.path.dirname(os.path.realpath(__file__))
